defmodule Pescarte.Button do
  @moduledoc false

  use Surface.Component

  @doc """
  The button type, defaults to "button", mainly used for instances like modal X to close style buttons
  where you don't want to set a type at all. Setting to nil makes button have no type.
  """
  prop type, :string, default: "button"

  @doc "The role for the button"
  prop role, :string

  @doc "The label of the button, when no content (default slot) is provided"
  prop label, :string

  @doc "The value for the button"
  prop value, :string

  @doc "Force button to show active state"
  prop active, :boolean, default: false

  @doc "Transparent Button with colored border"
  prop outline, :boolean, default: false

  @doc "Force button to show disabled state"
  prop disabled, :boolean

  @doc "Additional classes for the button"
  prop class, :css_class, default: []

  @doc """
  Additional attributes to add onto the generated element
  """
  prop opts, :keyword, default: []

  @doc """
  The content of the generated `<button>` element. If no content is provided,
  the value of property `label` is used instead.
  """
  slot default

  def render(assigns) do
    ~F"""
    <button {=@type} {=@role} {=@disabled}>
      <#slot>{@label}</#slot>
    </button>
    """
  end
end
