defmodule Pescarte.Icon do
  @moduledoc false

  use Surface.Component

  @icons_path List.to_string(:code.priv_dir(:pescarte)) <> "/static/icons/"

  @available_icons ~w(
    accounts
    agenda
    compilation
    filter
    home
    image
    message
    new_account
    new_file
    report
    search
  )

  @doc "The icon name to be used"
  prop name, :string, values!: @available_icons

  @doc "Additional classes for the button"
  prop class, :css_class, default: []

  def render(assigns) do
    ~F"""
    <figure>
      <img src={build_icon_path(@name)} alt={get_alt_text(@name)}>
    </figure>
    """
  end

  def build_icon_path(icon_name) do
    @icons_path <> Atom.to_string(icon_name) <> ".svg"
  end

  def get_alt_text(:accounts) do
    "Ícone que representa duas ou mais pessoas"
  end

  def get_alt_text(:agenda) do
    "Ícone que representa um calendário"
  end

  def get_alt_text(:compilation) do
    "Ícone que representa a junção de arquivos"
  end

  def get_alt_text(:file) do
    "Ícone que representa um arquivo"
  end

  def get_alt_text(:filter) do
    "Ícone que representa um filtro de itens"
  end

  def get_alt_text(:home) do
    "Ícone que representa uma casa"
  end

  def get_alt_text(:image) do
    "Ícone que representa uma imagem"
  end

  def get_alt_text(:message) do
    "Ícone que representa uma mensagem ou email"
  end

  def get_alt_text(:new_account) do
    "Ícone que representa a criação de uma nova conta"
  end

  def get_alt_text(:new_file) do
    "Ícone que representa a criação de um novo arquivo"
  end

  def get_alt_text(:seach) do
    "Ícone que representa uma lupa para procura de itens"
  end
end
